#[repr(transparent)]pub struct Secp256k1PublicKey(pub <Secp256k1 as Curve>::PublicKey);Tuple Fields
0: <Secp256k1 as Curve>::PublicKeyTrait Implementations
Sourceimpl<'arbitrary> Arbitrary<'arbitrary> for Secp256k1PublicKey
impl<'arbitrary> Arbitrary<'arbitrary> for Secp256k1PublicKey
Sourcefn arbitrary(u: &mut Unstructured<'arbitrary>) -> Result<Self>
fn arbitrary(u: &mut Unstructured<'arbitrary>) -> Result<Self>
Generate an arbitrary value of
Self from the given unstructured data. Read moreSourcefn arbitrary_take_rest(u: Unstructured<'arbitrary>) -> Result<Self>
fn arbitrary_take_rest(u: Unstructured<'arbitrary>) -> Result<Self>
Generate an arbitrary value of
Self from the entirety of the given
unstructured data. Read moreSourceimpl BorshDeserialize for Secp256k1PublicKey
impl BorshDeserialize for Secp256k1PublicKey
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Secp256k1PublicKey
impl BorshSerialize for Secp256k1PublicKey
Sourceimpl Clone for Secp256k1PublicKey
impl Clone for Secp256k1PublicKey
Sourcefn clone(&self) -> Secp256k1PublicKey
fn clone(&self) -> Secp256k1PublicKey
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Secp256k1PublicKey
impl Debug for Secp256k1PublicKey
Sourceimpl<'de> Deserialize<'de> for Secp256k1PublicKey
impl<'de> Deserialize<'de> for Secp256k1PublicKey
Sourcefn deserialize<__D>(deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for Secp256k1PublicKey
impl Display for Secp256k1PublicKey
Sourceimpl FromStr for Secp256k1PublicKey
impl FromStr for Secp256k1PublicKey
Sourceimpl Hash for Secp256k1PublicKey
impl Hash for Secp256k1PublicKey
Sourceimpl Ord for Secp256k1PublicKey
impl Ord for Secp256k1PublicKey
Sourcefn cmp(&self, other: &Secp256k1PublicKey) -> Ordering
fn cmp(&self, other: &Secp256k1PublicKey) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Secp256k1PublicKey
impl PartialEq for Secp256k1PublicKey
Sourceimpl PartialOrd for Secp256k1PublicKey
impl PartialOrd for Secp256k1PublicKey
Sourceimpl Serialize for Secp256k1PublicKeywhere
Self: Display,
impl Serialize for Secp256k1PublicKeywhere
Self: Display,
impl Copy for Secp256k1PublicKey
impl Eq for Secp256k1PublicKey
impl StructuralPartialEq for Secp256k1PublicKey